#ifndef _TNOS_68K_H
#define _TNOS_68K_H

#ifndef TNOS
#define TNOS
#endif

#define _TYPES2_ 1
extern char sys_errlist[];
#include <errno.h>
#include <ctype.h>
#include <sys/types.h>
#undef LARGEDATA
#define SEEK_SET 0
#define SEEK_CUR 1
#define SEEK_END 2
#define FA_DIREC 0x80
#define _IOFBF 0
#define const
#define volatile
#define huge
#define _SS 1
#define _SP 1
#define _DS 1
#define _DI 1
#define stdaux stderr
#define stdprn stderr
#define filelength _gs_size
#define O_BINARY 0
#define O_RDONLY 1
#define P_WAIT 0
#define fclose _fclose
extern unsigned _stklen;
#define MSPTICK 20
#define _stklen ((unsigned) 8192)

void clrscr(), free();
char *malloc();
char *strchr(), *strrchr(), *strstr(), *strpbrk();

/* Template for contents of jmp_buf for 68302 */
struct env {
	unsigned	_pc;
	unsigned	_d0;
	unsigned	_d1;
	unsigned	_d2;
	unsigned	_d3;
	unsigned	_d4;
	unsigned	_d5;
	unsigned	_d6;
	unsigned	_d7;
	unsigned	_a0;
	unsigned	_a1;
	unsigned	_a2;
	unsigned	_a3;
	unsigned	_a4;
	unsigned	_a5;
	unsigned	_a6;
	unsigned	_a7;
	unsigned	_xtra;
};

#define TNOS_SP(p) (((struct env *)p->env)->_a7)
#define TNOS_PC(p) (((struct env *)p->env)->_pc)

#endif	/* _TNOS_68K_H */
